#include <VirtualWire.h>

const int buttonPin = 8;  // the number of the pushbutton pin
const int txPin = 11;     // the number of the tx module
const int rxPin = 12;     // the number of the rx module
const int ledPin = 13;

const int bluePin  = 5;
const int redPin   = 6;
const int greenPin = 7;

int buttonState = 0;      // variable for reading the pushbutton status

char *txBuffer;           // 
int color;
int roundCounter;

void selectAndTxRandColor() {
  color = random(5,8); //first inclusive, second exclusive
  digitalWrite(bluePin, LOW);
  digitalWrite(redPin, LOW);
  digitalWrite(greenPin, LOW);
  digitalWrite(color, HIGH);
  txColor();
  fastBlink(20);
}

void txColor() {
  txBuffer = "0"; 
  if (color == bluePin) {
    txBuffer = "5"; 
  } else if (color == redPin) {
    txBuffer = "6"; 
  } else if (color == greenPin) {
    txBuffer = "7"; 
  }
  vw_send((uint8_t *) txBuffer, strlen(txBuffer));
  vw_wait_tx(); //wait until message is sent completely
  Serial.println("tx color");
}

void blink(int times) {
  for (int i = 0; i < times; i++) {
    digitalWrite(ledPin, HIGH);
    delay(100);
    digitalWrite(ledPin, LOW);
    delay(100);
  }
}

void fastBlink(int times) {
  for (int i = 0; i < times; i++) {
    digitalWrite(ledPin, HIGH);
    delay(10);
    digitalWrite(ledPin, LOW);
    delay(10);
  }
}

void setup() {
  pinMode(ledPin,OUTPUT); //LED
  Serial.begin(9600);
  Serial.println("init debug");
  

  vw_set_ptt_inverted(true);//required for sender/receiver modules
  vw_set_tx_pin(txPin);
  vw_set_rx_pin(rxPin);
  vw_setup(4000);//speed in bps
  vw_rx_start();//start receiving at receiver module
  selectAndTxRandColor();
  
  
  roundCounter = 0;
  Serial.println("init");
}

void loop() {
  roundCounter++;
  uint8_t buf[VW_MAX_MESSAGE_LEN];
  uint8_t buflen = VW_MAX_MESSAGE_LEN;

  if (vw_get_message(buf, &buflen)) { // Non-blocking
    if(buf[0]=='5'){
      Serial.println("Received color: " + buf[0]);
      if (color == bluePin) {
        selectAndTxRandColor();
      }
    } else if(buf[0]=='6'){
      Serial.println("Received color: " + buf[0]);
      if (color == redPin) {
        selectAndTxRandColor();
      }
    } else if(buf[0]=='7'){
      Serial.println("Received color: " + buf[0]);
      if (color == greenPin) {
        selectAndTxRandColor();
      }
    } else {
      fastBlink(100);
      Serial.println("Received bad color: " + buf[0]);
    }
    digitalWrite(ledPin, HIGH);
    delay(500);
    digitalWrite(ledPin, LOW);
  }
  

  buttonState = digitalRead(buttonPin);
  if (buttonState == HIGH) {
    selectAndTxRandColor();
  }

  delay(10);
  //reset roundCounter
  if (roundCounter > 100) {
    roundCounter = 0;
    txColor();
  }
}
